=== modified file 'mandos'
--- mandos	2010-08-23 19:23:15 +0000
+++ mandos	2010-09-02 18:36:36 +0000
@@ -83,7 +83,7 @@
 
 version = "1.0.14"
 
-logger = logging.Logger(u'mandos')
+logger = logging.getLogger(u'mandos')
 syslogger = (logging.handlers.SysLogHandler
              (facility = logging.handlers.SysLogHandler.LOG_DAEMON,
               address = "/dev/log"))
@@ -332,7 +332,7 @@
         self.approved_duration = string_to_delta(
             config[u"approved_duration"])
         self.changedstate = multiprocessing_manager.Condition(multiprocessing_manager.Lock())
-
+    
     def send_changedstate(self):
         self.changedstate.acquire()
         self.changedstate.notify_all()
@@ -702,6 +702,7 @@
     # dbus.service.Object doesn't use super(), so we can't either.
     
     def __init__(self, bus = None, *args, **kwargs):
+        self._approvals_pending = 0
         self.bus = bus
         Client.__init__(self, *args, **kwargs)
         # Only now, when this client is initialized, can it show up on
@@ -712,6 +713,21 @@
         DBusObjectWithProperties.__init__(self, self.bus,
                                           self.dbus_object_path)
     
+    def _get_approvals_pending(value):
+        return self._approvals_pending
+    def _set_approvals_pending(value):
+        old_value = self._approvals_pending
+        self._approvals_pending = value
+        bval = bool(value)
+        if bval is bool(old_value):
+            dbus_bool = dbus.Boolean(bval, variant_level=1)
+            self.PropertyChanged(dbus.String(u"approved_pending"),
+                                 dbus_bool)
+        return value
+    approvals_pending = property(_get_approvals_pending,
+                                 _set_approvals_pending)
+    del _get_approvals_pending, _set_approvals_pending
+    
     @staticmethod
     def _datetime_to_dbus(dt, variant_level=0):
         """Convert a UTC datetime.datetime() to a D-Bus type."""
@@ -813,9 +829,6 @@
     def approve(self, value=True):
         self._approved = value
         gobject.timeout_add(self._timedelta_to_milliseconds(self.approved_duration, self._reset_approved))
-
-    def approved_pending(self):
-        return self.approvals_pending > 0
     
     
     ## D-Bus methods, signals & properties
@@ -845,25 +858,19 @@
     @dbus.service.signal(_interface)
     def GotSecret(self):
         "D-Bus signal"
-        if self.approved_pending():
-            self.PropertyChanged(dbus.String(u"checker_running"),
-                                 dbus.Boolean(False, variant_level=1))
+        pass
     
     # Rejected - signal
     @dbus.service.signal(_interface, signature=u"s")
     def Rejected(self, reason):
         "D-Bus signal"
-        if self.approved_pending():
-            self.PropertyChanged(dbus.String(u"checker_running"),
-                                 dbus.Boolean(False, variant_level=1))
+        pass
     
     # NeedApproval - signal
     @dbus.service.signal(_interface, signature=u"db")
     def NeedApproval(self, timeout, default):
         "D-Bus signal"
-        if not self.approved_pending():
-            self.PropertyChanged(dbus.String(u"approved_pending"),
-                                 dbus.Boolean(True, variant_level=1))
+        pass
     
     ## Methods
 
@@ -905,7 +912,7 @@
     # approved_pending - property
     @dbus_service_property(_interface, signature=u"b", access=u"read")
     def approved_pending_dbus_property(self):
-        return dbus.Boolean(self.approved_pending())
+        return dbus.Boolean(bool(self.approvals_pending))
     
     # approved_by_default - property
     @dbus_service_property(_interface, signature=u"b",
@@ -1491,12 +1498,12 @@
                 parent_pipe.send(('function',))
             else:
                 parent_pipe.send(('data', client_object.__getattribute__(attrname)))
-
+        
         if command == 'setattr':
             attrname = request[1]
             value = request[2]
             setattr(client_object, attrname, value)
-            
+        
         return True
 
 

=== modified file 'mandos-monitor'
--- mandos-monitor	2009-12-25 23:13:47 +0000
+++ mandos-monitor	2010-08-31 18:22:25 +0000
@@ -23,11 +23,14 @@
 
 locale.setlocale(locale.LC_ALL, u'')
 
+import logging
+logging.getLogger('dbus.proxies').setLevel(logging.CRITICAL)
+
 # Some useful constants
 domain = 'se.bsnet.fukt'
 server_interface = domain + '.Mandos'
 client_interface = domain + '.Mandos.Client'
-version = "1.0.14"
+version = "1.0.15"
 
 # Always run in monochrome mode
 urwid.curses_display.curses.has_colors = lambda : False
@@ -50,7 +53,7 @@
                                      self.property_changed,
                                      client_interface,
                                      byte_arrays=True)
-
+        
         self.properties.update(
             self.proxy.GetAll(client_interface,
                               dbus_interface = dbus.PROPERTIES_IFACE))
@@ -101,6 +104,10 @@
                                      self.got_secret,
                                      client_interface,
                                      byte_arrays=True)
+        self.proxy.connect_to_signal(u"NeedApproval",
+                                     self.need_approval,
+                                     client_interface,
+                                     byte_arrays=True)
         self.proxy.connect_to_signal(u"Rejected",
                                      self.rejected,
                                      client_interface,
@@ -108,9 +115,9 @@
     
     def checker_completed(self, exitstatus, condition, command):
         if exitstatus == 0:
-            self.logger(u'Checker for client %s (command "%s")'
-                        u' was successful'
-                        % (self.properties[u"name"], command))
+            #self.logger(u'Checker for client %s (command "%s")'
+            #            u' was successful'
+            #            % (self.properties[u"name"], command))
             return
         if os.WIFEXITED(condition):
             self.logger(u'Checker for client %s (command "%s")'
@@ -131,16 +138,25 @@
         self.logger(u'Checker for client %s completed mysteriously')
     
     def checker_started(self, command):
-        self.logger(u'Client %s started checker "%s"'
-                    % (self.properties[u"name"], unicode(command)))
+        #self.logger(u'Client %s started checker "%s"'
+        #            % (self.properties[u"name"], unicode(command)))
+        pass
     
     def got_secret(self):
         self.logger(u'Client %s received its secret'
                     % self.properties[u"name"])
     
-    def rejected(self):
-        self.logger(u'Client %s was rejected'
-                    % self.properties[u"name"])
+    def need_approval(self, timeout, default):
+        if not default:
+            message = u'Client %s needs approval within %s seconds'
+        else:
+            message = u'Client %s will get its secret in %s seconds'
+        self.logger(message
+                    % (self.properties[u"name"], timeout/1000))
+    
+    def rejected(self, reason):
+        self.logger(u'Client %s was rejected; reason: %s'
+                    % (self.properties[u"name"], reason))
     
     def selectable(self):
         """Make this a "selectable" widget.
@@ -225,6 +241,10 @@
 #             self.proxy.unpause()
 #         elif key == u"RET":
 #             self.open()
+        elif key == u"+":
+            self.proxy.Approve(True)
+        elif key == u"-":
+            self.proxy.Approve(False)
         else:
             return key
     

